from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbCls:
	"""Bb commands group definition. 8352 total commands, 31 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bb", core, parent)

	@property
	def arbitrary(self):
		"""arbitrary commands group. 10 Sub-classes, 2 commands."""
		if not hasattr(self, '_arbitrary'):
			from .Arbitrary import ArbitraryCls
			self._arbitrary = ArbitraryCls(self._core, self._cmd_group)
		return self._arbitrary

	@property
	def btooth(self):
		"""btooth commands group. 21 Sub-classes, 18 commands."""
		if not hasattr(self, '_btooth'):
			from .Btooth import BtoothCls
			self._btooth = BtoothCls(self._core, self._cmd_group)
		return self._btooth

	@property
	def c2K(self):
		"""c2K commands group. 13 Sub-classes, 5 commands."""
		if not hasattr(self, '_c2K'):
			from .C2K import C2KCls
			self._c2K = C2KCls(self._core, self._cmd_group)
		return self._c2K

	@property
	def coder(self):
		"""coder commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coder'):
			from .Coder import CoderCls
			self._coder = CoderCls(self._core, self._cmd_group)
		return self._coder

	@property
	def dab(self):
		"""dab commands group. 11 Sub-classes, 7 commands."""
		if not hasattr(self, '_dab'):
			from .Dab import DabCls
			self._dab = DabCls(self._core, self._cmd_group)
		return self._dab

	@property
	def dme(self):
		"""dme commands group. 14 Sub-classes, 14 commands."""
		if not hasattr(self, '_dme'):
			from .Dme import DmeCls
			self._dme = DmeCls(self._core, self._cmd_group)
		return self._dme

	@property
	def eutra(self):
		"""eutra commands group. 19 Sub-classes, 8 commands."""
		if not hasattr(self, '_eutra'):
			from .Eutra import EutraCls
			self._eutra = EutraCls(self._core, self._cmd_group)
		return self._eutra

	@property
	def evdo(self):
		"""evdo commands group. 13 Sub-classes, 8 commands."""
		if not hasattr(self, '_evdo'):
			from .Evdo import EvdoCls
			self._evdo = EvdoCls(self._core, self._cmd_group)
		return self._evdo

	@property
	def gbas(self):
		"""gbas commands group. 8 Sub-classes, 9 commands."""
		if not hasattr(self, '_gbas'):
			from .Gbas import GbasCls
			self._gbas = GbasCls(self._core, self._cmd_group)
		return self._gbas

	@property
	def gnpr(self):
		"""gnpr commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_gnpr'):
			from .Gnpr import GnprCls
			self._gnpr = GnprCls(self._core, self._cmd_group)
		return self._gnpr

	@property
	def gnss(self):
		"""gnss commands group. 27 Sub-classes, 6 commands."""
		if not hasattr(self, '_gnss'):
			from .Gnss import GnssCls
			self._gnss = GnssCls(self._core, self._cmd_group)
		return self._gnss

	@property
	def graphics(self):
		"""graphics commands group. 2 Sub-classes, 6 commands."""
		if not hasattr(self, '_graphics'):
			from .Graphics import GraphicsCls
			self._graphics = GraphicsCls(self._core, self._cmd_group)
		return self._graphics

	@property
	def gsm(self):
		"""gsm commands group. 17 Sub-classes, 7 commands."""
		if not hasattr(self, '_gsm'):
			from .Gsm import GsmCls
			self._gsm = GsmCls(self._core, self._cmd_group)
		return self._gsm

	@property
	def huwb(self):
		"""huwb commands group. 13 Sub-classes, 12 commands."""
		if not hasattr(self, '_huwb'):
			from .Huwb import HuwbCls
			self._huwb = HuwbCls(self._core, self._cmd_group)
		return self._huwb

	@property
	def impairment(self):
		"""impairment commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_impairment'):
			from .Impairment import ImpairmentCls
			self._impairment = ImpairmentCls(self._core, self._cmd_group)
		return self._impairment

	@property
	def info(self):
		"""info commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_info'):
			from .Info import InfoCls
			self._info = InfoCls(self._core, self._cmd_group)
		return self._info

	@property
	def lora(self):
		"""lora commands group. 7 Sub-classes, 6 commands."""
		if not hasattr(self, '_lora'):
			from .Lora import LoraCls
			self._lora = LoraCls(self._core, self._cmd_group)
		return self._lora

	@property
	def mccw(self):
		"""mccw commands group. 5 Sub-classes, 2 commands."""
		if not hasattr(self, '_mccw'):
			from .Mccw import MccwCls
			self._mccw = MccwCls(self._core, self._cmd_group)
		return self._mccw

	@property
	def nfc(self):
		"""nfc commands group. 10 Sub-classes, 12 commands."""
		if not hasattr(self, '_nfc'):
			from .Nfc import NfcCls
			self._nfc = NfcCls(self._core, self._cmd_group)
		return self._nfc

	@property
	def nr5G(self):
		"""nr5G commands group. 27 Sub-classes, 7 commands."""
		if not hasattr(self, '_nr5G'):
			from .Nr5G import Nr5GCls
			self._nr5G = Nr5GCls(self._core, self._cmd_group)
		return self._nr5G

	@property
	def ofdm(self):
		"""ofdm commands group. 16 Sub-classes, 18 commands."""
		if not hasattr(self, '_ofdm'):
			from .Ofdm import OfdmCls
			self._ofdm = OfdmCls(self._core, self._cmd_group)
		return self._ofdm

	@property
	def path(self):
		"""path commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_path'):
			from .Path import PathCls
			self._path = PathCls(self._core, self._cmd_group)
		return self._path

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def pramp(self):
		"""pramp commands group. 5 Sub-classes, 2 commands."""
		if not hasattr(self, '_pramp'):
			from .Pramp import PrampCls
			self._pramp = PrampCls(self._core, self._cmd_group)
		return self._pramp

	@property
	def progress(self):
		"""progress commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_progress'):
			from .Progress import ProgressCls
			self._progress = ProgressCls(self._core, self._cmd_group)
		return self._progress

	@property
	def tdscdma(self):
		"""tdscdma commands group. 12 Sub-classes, 6 commands."""
		if not hasattr(self, '_tdscdma'):
			from .Tdscdma import TdscdmaCls
			self._tdscdma = TdscdmaCls(self._core, self._cmd_group)
		return self._tdscdma

	@property
	def trigger(self):
		"""trigger commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def vor(self):
		"""vor commands group. 10 Sub-classes, 3 commands."""
		if not hasattr(self, '_vor'):
			from .Vor import VorCls
			self._vor = VorCls(self._core, self._cmd_group)
		return self._vor

	@property
	def w3Gpp(self):
		"""w3Gpp commands group. 13 Sub-classes, 5 commands."""
		if not hasattr(self, '_w3Gpp'):
			from .W3Gpp import W3GppCls
			self._w3Gpp = W3GppCls(self._core, self._cmd_group)
		return self._w3Gpp

	@property
	def wlnn(self):
		"""wlnn commands group. 9 Sub-classes, 8 commands."""
		if not hasattr(self, '_wlnn'):
			from .Wlnn import WlnnCls
			self._wlnn = WlnnCls(self._core, self._cmd_group)
		return self._wlnn

	@property
	def ils(self):
		"""ils commands group. 7 Sub-classes, 3 commands."""
		if not hasattr(self, '_ils'):
			from .Ils import IlsCls
			self._ils = IlsCls(self._core, self._cmd_group)
		return self._ils

	def get_cfactor(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:CFACtor \n
		Snippet: value: float = driver.source.bb.get_cfactor() \n
		Queries the crest factor of the baseband signal. \n
			:return: cfactor: float Range: 0 to 100, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:CFACtor?')
		return Conversions.str_to_float(response)

	def get_foffset(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:FOFFset \n
		Snippet: value: float = driver.source.bb.get_foffset() \n
		Sets a frequency offset for the internal/external baseband signal. The offset affects the generated baseband signal. \n
			:return: foffset: float Range: depends on the installed options , Unit: Hz E.g. -60 MHz to +60 MHz (base unit)
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:FOFFset?')
		return Conversions.str_to_float(response)

	def set_foffset(self, foffset: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:FOFFset \n
		Snippet: driver.source.bb.set_foffset(foffset = 1.0) \n
		Sets a frequency offset for the internal/external baseband signal. The offset affects the generated baseband signal. \n
			:param foffset: float Range: depends on the installed options , Unit: Hz E.g. -60 MHz to +60 MHz (base unit)
		"""
		param = Conversions.decimal_value_to_str(foffset)
		self._core.io.write(f'SOURce<HwInstance>:BB:FOFFset {param}')

	# noinspection PyTypeChecker
	def get_iq_gain(self) -> enums.IqGain:
		"""SCPI: [SOURce<HW>]:BB:IQGain \n
		Snippet: value: enums.IqGain = driver.source.bb.get_iq_gain() \n
		Optimizes the modulation of the I/Q modulator for a subset of measurement requirement. \n
			:return: ipartq_gain: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:IQGain?')
		return Conversions.str_to_scalar_enum(response, enums.IqGain)

	def set_iq_gain(self, ipartq_gain: enums.IqGain) -> None:
		"""SCPI: [SOURce<HW>]:BB:IQGain \n
		Snippet: driver.source.bb.set_iq_gain(ipartq_gain = enums.IqGain.DB0) \n
		Optimizes the modulation of the I/Q modulator for a subset of measurement requirement. \n
			:param ipartq_gain: DBM4| DBM2| DB0| DB2| DB4| DB8| DB6 Dynamic range of 16 dB divided into 2 dB steps. DB0|DB2|DB4|DB6|DB8 Activates the specified gain of 0 dB, +2 dB, +4 dB, +6 dB, +8 dB DBM2|DBM4 Activates the specified gain of -2 dB, -4 dB
		"""
		param = Conversions.enum_scalar_to_str(ipartq_gain, enums.IqGain)
		self._core.io.write(f'SOURce<HwInstance>:BB:IQGain {param}')

	def get_pgain(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:PGAin \n
		Snippet: value: float = driver.source.bb.get_pgain() \n
		No command help available \n
			:return: pgain: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:PGAin?')
		return Conversions.str_to_float(response)

	def set_pgain(self, pgain: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:PGAin \n
		Snippet: driver.source.bb.set_pgain(pgain = 1.0) \n
		No command help available \n
			:param pgain: No help available
		"""
		param = Conversions.decimal_value_to_str(pgain)
		self._core.io.write(f'SOURce<HwInstance>:BB:PGAin {param}')

	def get_poffset(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:POFFset \n
		Snippet: value: float = driver.source.bb.get_poffset() \n
		Sets the relative phase offset for the selected baseband signal. \n
			:return: poffset: float Range: 0 to 359.9, Unit: DEG
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:POFFset?')
		return Conversions.str_to_float(response)

	def set_poffset(self, poffset: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:POFFset \n
		Snippet: driver.source.bb.set_poffset(poffset = 1.0) \n
		Sets the relative phase offset for the selected baseband signal. \n
			:param poffset: float Range: 0 to 359.9, Unit: DEG
		"""
		param = Conversions.decimal_value_to_str(poffset)
		self._core.io.write(f'SOURce<HwInstance>:BB:POFFset {param}')

	# noinspection PyTypeChecker
	def get_route(self) -> enums.PathUniCodBbin:
		"""SCPI: [SOURce<HW>]:BB:ROUTe \n
		Snippet: value: enums.PathUniCodBbin = driver.source.bb.get_route() \n
		Selects the signal route for the internal/external baseband signal. \n
			:return: route: A
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ROUTe?')
		return Conversions.str_to_scalar_enum(response, enums.PathUniCodBbin)

	def set_route(self, route: enums.PathUniCodBbin) -> None:
		"""SCPI: [SOURce<HW>]:BB:ROUTe \n
		Snippet: driver.source.bb.set_route(route = enums.PathUniCodBbin.A) \n
		Selects the signal route for the internal/external baseband signal. \n
			:param route: A
		"""
		param = Conversions.enum_scalar_to_str(route, enums.PathUniCodBbin)
		self._core.io.write(f'SOURce<HwInstance>:BB:ROUTe {param}')

	def clone(self) -> 'BbCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BbCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SettingCls:
	"""Setting commands group definition. 5 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("setting", core, parent)

	@property
	def tmodel(self):
		"""tmodel commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tmodel'):
			from .Tmodel import TmodelCls
			self._tmodel = TmodelCls(self._core, self._cmd_group)
		return self._tmodel

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.tdscdma.setting.get_catalog() \n
		Queries the files with settings in the default directory. Listed are files with the file extension *.tdscdma. For general
		information on file handling in the default and in a specific directory, see section 'MMEMory Subsystem' in the R&S
		SMBVBuser manual. \n
			:return: catalog: filename1,filename2,... Returns a string of filenames separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TDSCdma:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:SETTing:LOAD \n
		Snippet: driver.source.bb.tdscdma.setting.load(filename = 'abc') \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.tdscdma. \n
			:param filename: 'filename' Filename or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:SETTing:LOAD {param}')

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:SETTing:STORe \n
		Snippet: driver.source.bb.tdscdma.setting.set_store(filename = 'abc') \n
		Stores the current settings into the selected file; the file extension (*.tdscdma) is assigned automatically. \n
			:param filename: string Filename or complete file path
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:SETTing:STORe {param}')

	def clone(self) -> 'SettingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SettingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DfreqCls:
	"""Dfreq commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dfreq", core, parent)

	def set(self, delta_freq: float, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CA:CELL<CH0>:DFReq \n
		Snippet: driver.source.bb.eutra.downlink.ca.cell.dfreq.set(delta_freq = 1.0, cellNull = repcap.CellNull.Default) \n
		Sets the frequency offset between the central frequency of the SCell and the frequency of the PCell. \n
			:param delta_freq: float Value range depends on the installed options, the number of cells and the cell bandwidth. Range: -40 to 40, Unit: MHz
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.decimal_value_to_str(delta_freq)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:CA:CELL{cellNull_cmd_val}:DFReq {param}')

	def get(self, cellNull=repcap.CellNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CA:CELL<CH0>:DFReq \n
		Snippet: value: float = driver.source.bb.eutra.downlink.ca.cell.dfreq.get(cellNull = repcap.CellNull.Default) \n
		Sets the frequency offset between the central frequency of the SCell and the frequency of the PCell. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: delta_freq: float Value range depends on the installed options, the number of cells and the cell bandwidth. Range: -40 to 40, Unit: MHz"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:CA:CELL{cellNull_cmd_val}:DFReq?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SbitsCls:
	"""Sbits commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sbits", core, parent)

	def set(self, pattern: str, bitcount: int, cellNull=repcap.CellNull.Default, indexNull=repcap.IndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:SSPBch<SSB(ST0)>:SL:SBITs \n
		Snippet: driver.source.bb.nr5G.node.cell.sspbch.sl.sbits.set(pattern = rawAbc, bitcount = 1, cellNull = repcap.CellNull.Default, indexNull = repcap.IndexNull.Default) \n
		Defines the spare bits for the PSBCH. \n
			:param pattern: 2 bits
			:param bitcount: integer Range: 2 to 2
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sspbch')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('pattern', pattern, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		indexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:SSPBch{indexNull_cmd_val}:SL:SBITs {param}'.rstrip())

	# noinspection PyTypeChecker
	class SbitsStruct(StructBase):
		"""Response structure. Fields: \n
			- Pattern: str: 2 bits
			- Bitcount: int: integer Range: 2 to 2"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Pattern'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: str = None
			self.Bitcount: int = None

	def get(self, cellNull=repcap.CellNull.Default, indexNull=repcap.IndexNull.Default) -> SbitsStruct:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:SSPBch<SSB(ST0)>:SL:SBITs \n
		Snippet: value: SbitsStruct = driver.source.bb.nr5G.node.cell.sspbch.sl.sbits.get(cellNull = repcap.CellNull.Default, indexNull = repcap.IndexNull.Default) \n
		Defines the spare bits for the PSBCH. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sspbch')
			:return: structure: for return value, see the help for SbitsStruct structure arguments."""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		indexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:SSPBch{indexNull_cmd_val}:SL:SBITs?', self.__class__.SbitsStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FileCls:
	"""File commands group definition. 7 total commands, 4 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)

	@property
	def day(self):
		"""day commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_day'):
			from .Day import DayCls
			self._day = DayCls(self._core, self._cmd_group)
		return self._day

	@property
	def month(self):
		"""month commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_month'):
			from .Month import MonthCls
			self._month = MonthCls(self._core, self._cmd_group)
		return self._month

	@property
	def prefix(self):
		"""prefix commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_prefix'):
			from .Prefix import PrefixCls
			self._prefix = PrefixCls(self._core, self._cmd_group)
		return self._prefix

	@property
	def year(self):
		"""year commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_year'):
			from .Year import YearCls
			self._year = YearCls(self._core, self._cmd_group)
		return self._year

	def get_number(self) -> int:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:[FILE]:NUMBer \n
		Snippet: value: int = driver.hardCopy.file.name.auto.file.get_number() \n
		Queries the number that is used as part of the file name for the next hard copy in automatic mode. At the beginning, the
		count starts at 0. The R&S SMBV100B searches the specified output directory for the highest number in the stored files.
		It increases this number by one to achieve a unique name for the new file. The resulting auto number is appended to the
		resulting file name with at least three digits. \n
			:return: number: integer Range: 0 to 999999
		"""
		response = self._core.io.query_str('HCOPy:FILE:NAME:AUTO:FILE:NUMBer?')
		return Conversions.str_to_int(response)

	def get_value(self) -> str:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:FILE \n
		Snippet: value: str = driver.hardCopy.file.name.auto.file.get_value() \n
		Queries the name of the automatically named hard copy file. An automatically generated file name consists of:
		<Prefix><YYYY><MM><DD><Number>.<Format>. You can activate each component separately, to individually design the file name. \n
			:return: file: string
		"""
		response = self._core.io.query_str('HCOPy:FILE:NAME:AUTO:FILE?')
		return trim_str_response(response)

	def clone(self) -> 'FileCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FileCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DeviationCls:
	"""Deviation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("deviation", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ModulationDevMode:
		"""SCPI: [SOURce<HW>]:AM:DEViation:MODE \n
		Snippet: value: enums.ModulationDevMode = driver.source.am.deviation.get_mode() \n
		Selects the coupling mode. The coupling mode parameter also determines the mode for fixing the total depth. \n
			:return: am_dev_mode: UNCoupled| TOTal| RATio UNCoupled Does not couple the LF signals. The deviation depth values of both paths are independent. TOTal Couples the deviation depth of both paths. RATio Couples the deviation depth ratio of both paths
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AM:DEViation:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ModulationDevMode)

	def set_mode(self, am_dev_mode: enums.ModulationDevMode) -> None:
		"""SCPI: [SOURce<HW>]:AM:DEViation:MODE \n
		Snippet: driver.source.am.deviation.set_mode(am_dev_mode = enums.ModulationDevMode.RATio) \n
		Selects the coupling mode. The coupling mode parameter also determines the mode for fixing the total depth. \n
			:param am_dev_mode: UNCoupled| TOTal| RATio UNCoupled Does not couple the LF signals. The deviation depth values of both paths are independent. TOTal Couples the deviation depth of both paths. RATio Couples the deviation depth ratio of both paths
		"""
		param = Conversions.enum_scalar_to_str(am_dev_mode, enums.ModulationDevMode)
		self._core.io.write(f'SOURce<HwInstance>:AM:DEViation:MODE {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OutputCls:
	"""Output commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	# noinspection PyTypeChecker
	def get_polarity(self) -> enums.NormalInverted:
		"""SCPI: [SOURce<HW>]:PGENerator:OUTPut:POLarity \n
		Snippet: value: enums.NormalInverted = driver.source.pgenerator.output.get_polarity() \n
		Sets the polarity of the pulse output signal. \n
			:return: polarity: NORMal| INVerted NORMal Outputs the pulse signal during the pulse width, that means during the high state. INVerted Inverts the pulse output signal polarity. The pulse output signal is suppressed during the pulse width, but provided during the low state.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PGENerator:OUTPut:POLarity?')
		return Conversions.str_to_scalar_enum(response, enums.NormalInverted)

	def set_polarity(self, polarity: enums.NormalInverted) -> None:
		"""SCPI: [SOURce<HW>]:PGENerator:OUTPut:POLarity \n
		Snippet: driver.source.pgenerator.output.set_polarity(polarity = enums.NormalInverted.INVerted) \n
		Sets the polarity of the pulse output signal. \n
			:param polarity: NORMal| INVerted NORMal Outputs the pulse signal during the pulse width, that means during the high state. INVerted Inverts the pulse output signal polarity. The pulse output signal is suppressed during the pulse width, but provided during the low state.
		"""
		param = Conversions.enum_scalar_to_str(polarity, enums.NormalInverted)
		self._core.io.write(f'SOURce<HwInstance>:PGENerator:OUTPut:POLarity {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:PGENerator:OUTPut:[STATe] \n
		Snippet: value: bool = driver.source.pgenerator.output.get_state() \n
		Activates the output of the pulse modulation signal. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PGENerator:OUTPut:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:PGENerator:OUTPut:[STATe] \n
		Snippet: driver.source.pgenerator.output.set_state(state = False) \n
		Activates the output of the pulse modulation signal. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:PGENerator:OUTPut:STATe {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Id1Cls:
	"""Id1 commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("id1", core, parent)

	def set(self, ident: int, userIx=repcap.UserIx.Default, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:SCRambling:CELL<ST>:DMRS:ID1 \n
		Snippet: driver.source.bb.eutra.downlink.user.scrambling.cell.dmrs.id1.set(ident = 1, userIx = repcap.UserIx.Default, cell = repcap.Cell.Default) \n
		Sets the DMRS scrambling identity. \n
			:param ident: integer Range: 0 to 503
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
		"""
		param = Conversions.decimal_value_to_str(ident)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:SCRambling:CELL{cell_cmd_val}:DMRS:ID1 {param}')

	def get(self, userIx=repcap.UserIx.Default, cell=repcap.Cell.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:SCRambling:CELL<ST>:DMRS:ID1 \n
		Snippet: value: int = driver.source.bb.eutra.downlink.user.scrambling.cell.dmrs.id1.get(userIx = repcap.UserIx.Default, cell = repcap.Cell.Default) \n
		Sets the DMRS scrambling identity. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: ident: integer Range: 0 to 503"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:SCRambling:CELL{cell_cmd_val}:DMRS:ID1?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AltModulationCls:
	"""AltModulation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("altModulation", core, parent)

	def set(self, alt_modulation: enums.ModulationC, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:ALTModulation \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.altModulation.set(alt_modulation = enums.ModulationC.QAM16, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the alternative modulation (see 'Randomly varying modulation and number of codes (Type 3i) settings') . \n
			:param alt_modulation: QPSK| QAM16| QAM64
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.enum_scalar_to_str(alt_modulation, enums.ModulationC)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:ALTModulation {param}')

	# noinspection PyTypeChecker
	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> enums.ModulationC:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:HSDPa:HSET:ALTModulation \n
		Snippet: value: enums.ModulationC = driver.source.bb.w3Gpp.bstation.channel.hsdpa.hset.altModulation.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the alternative modulation (see 'Randomly varying modulation and number of codes (Type 3i) settings') . \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: alt_modulation: QPSK| QAM16| QAM64"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:HSDPa:HSET:ALTModulation?')
		return Conversions.str_to_scalar_enum(response, enums.ModulationC)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NameCls:
	"""Name commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("name", core, parent)

	def set(self, dig_iq_hs_ch_name: str, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:CHANnel<ST0>:NAME \n
		Snippet: driver.source.iq.output.digital.channel.name.set(dig_iq_hs_ch_name = 'abc', channelNull = repcap.ChannelNull.Default) \n
		Sets the channel name. \n
			:param dig_iq_hs_ch_name: string
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.value_to_quoted_str(dig_iq_hs_ch_name)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce:IQ:OUTPut:DIGital:CHANnel{channelNull_cmd_val}:NAME {param}')

	def get(self, channelNull=repcap.ChannelNull.Default) -> str:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:CHANnel<ST0>:NAME \n
		Snippet: value: str = driver.source.iq.output.digital.channel.name.get(channelNull = repcap.ChannelNull.Default) \n
		Sets the channel name. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: dig_iq_hs_ch_name: string"""
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce:IQ:OUTPut:DIGital:CHANnel{channelNull_cmd_val}:NAME?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PppCls:
	"""Ppp commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ppp", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:PPP:[STATe] \n
		Snippet: value: bool = driver.source.bb.dme.id.ppp.get_state() \n
		Sets the state of the pair of pulse pairs for the ID signal generation. When enabled a pair of pulse pairs is transmitted
		during the set [:SOURce<hw>][:BB]:DME:ID:RATE. \n
			:return: pair_of_pulse_pair: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:PPP:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, pair_of_pulse_pair: bool) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:PPP:[STATe] \n
		Snippet: driver.source.bb.dme.id.ppp.set_state(pair_of_pulse_pair = False) \n
		Sets the state of the pair of pulse pairs for the ID signal generation. When enabled a pair of pulse pairs is transmitted
		during the set [:SOURce<hw>][:BB]:DME:ID:RATE. \n
			:param pair_of_pulse_pair: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(pair_of_pulse_pair)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:PPP:STATe {param}')



from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UciCls:
	"""Uci commands group definition. 9 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uci", core, parent)

	@property
	def bits(self):
		"""bits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bits'):
			from .Bits import BitsCls
			self._bits = BitsCls(self._core, self._cmd_group)
		return self._bits

	@property
	def crate(self):
		"""crate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_crate'):
			from .Crate import CrateCls
			self._crate = CrateCls(self._core, self._cmd_group)
		return self._crate

	@property
	def cs1Bits(self):
		"""cs1Bits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cs1Bits'):
			from .Cs1Bits import Cs1BitsCls
			self._cs1Bits = Cs1BitsCls(self._core, self._cmd_group)
		return self._cs1Bits

	@property
	def cs1Pattern(self):
		"""cs1Pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cs1Pattern'):
			from .Cs1Pattern import Cs1PatternCls
			self._cs1Pattern = Cs1PatternCls(self._core, self._cmd_group)
		return self._cs1Pattern

	@property
	def cs2Bits(self):
		"""cs2Bits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cs2Bits'):
			from .Cs2Bits import Cs2BitsCls
			self._cs2Bits = Cs2BitsCls(self._core, self._cmd_group)
		return self._cs2Bits

	@property
	def cs2Pattern(self):
		"""cs2Pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cs2Pattern'):
			from .Cs2Pattern import Cs2PatternCls
			self._cs2Pattern = Cs2PatternCls(self._core, self._cmd_group)
		return self._cs2Pattern

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	@property
	def srpt(self):
		"""srpt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srpt'):
			from .Srpt import SrptCls
			self._srpt = SrptCls(self._core, self._cmd_group)
		return self._srpt

	def clone(self) -> 'UciCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UciCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReferenceCls:
	"""Reference commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("reference", core, parent)

	def set(self, reference: float, vehicle=repcap.Vehicle.Default, obscuredArea=repcap.ObscuredArea.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:AREA<CH>:REFerence \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.full.area.reference.set(reference = 1.0, vehicle = repcap.Vehicle.Default, obscuredArea = repcap.ObscuredArea.Default) \n
		Defines the reference starting position (in km) or time stamp (in s) of a specific obscured zone. \n
			:param reference: float Range: 0 to 1E4
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:param obscuredArea: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Area')
		"""
		param = Conversions.decimal_value_to_str(reference)
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		obscuredArea_cmd_val = self._cmd_group.get_repcap_cmd_value(obscuredArea, repcap.ObscuredArea)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:AREA{obscuredArea_cmd_val}:REFerence {param}')

	def get(self, vehicle=repcap.Vehicle.Default, obscuredArea=repcap.ObscuredArea.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:AREA<CH>:REFerence \n
		Snippet: value: float = driver.source.bb.gnss.receiver.v.environment.full.area.reference.get(vehicle = repcap.Vehicle.Default, obscuredArea = repcap.ObscuredArea.Default) \n
		Defines the reference starting position (in km) or time stamp (in s) of a specific obscured zone. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:param obscuredArea: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Area')
			:return: reference: float Range: 0 to 1E4"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		obscuredArea_cmd_val = self._cmd_group.get_repcap_cmd_value(obscuredArea, repcap.ObscuredArea)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:AREA{obscuredArea_cmd_val}:REFerence?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GbasCls:
	"""Gbas commands group definition. 190 total commands, 8 Subgroups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gbas", core, parent)

	@property
	def clipping(self):
		"""clipping commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clipping'):
			from .Clipping import ClippingCls
			self._clipping = ClippingCls(self._core, self._cmd_group)
		return self._clipping

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def filterPy(self):
		"""filterPy commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def mset(self):
		"""mset commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_mset'):
			from .Mset import MsetCls
			self._mset = MsetCls(self._core, self._cmd_group)
		return self._mset

	@property
	def setting(self):
		"""setting commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import SettingCls
			self._setting = SettingCls(self._core, self._cmd_group)
		return self._setting

	@property
	def trigger(self):
		"""trigger commands group. 5 Sub-classes, 5 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def vdb(self):
		"""vdb commands group. 12 Sub-classes, 1 commands."""
		if not hasattr(self, '_vdb'):
			from .Vdb import VdbCls
			self._vdb = VdbCls(self._core, self._cmd_group)
		return self._vdb

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import WaveformCls
			self._waveform = WaveformCls(self._core, self._cmd_group)
		return self._waveform

	def get_gpow(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GBAS:GPOW \n
		Snippet: value: bool = driver.source.bb.gbas.get_gpow() \n
		Enables gated power mode. \n
			:return: gpow: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:GPOW?')
		return Conversions.str_to_bool(response)

	def set_gpow(self, gpow: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:GPOW \n
		Snippet: driver.source.bb.gbas.set_gpow(gpow = False) \n
		Enables gated power mode. \n
			:param gpow: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(gpow)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:GPOW {param}')

	def get_mf_channels(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GBAS:MFCHannels \n
		Snippet: value: bool = driver.source.bb.gbas.get_mf_channels() \n
		No command help available \n
			:return: mfch: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:MFCHannels?')
		return Conversions.str_to_bool(response)

	def set_mf_channels(self, mfch: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:MFCHannels \n
		Snippet: driver.source.bb.gbas.set_mf_channels(mfch = False) \n
		No command help available \n
			:param mfch: No help available
		"""
		param = Conversions.bool_to_str(mfch)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:MFCHannels {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.GbasMode:
		"""SCPI: [SOURce<HW>]:BB:GBAS:MODE \n
		Snippet: value: enums.GbasMode = driver.source.bb.gbas.get_mode() \n
		Sets the GBAS mode. Select between GBAS (LAAS) header information or SCAT-I header information. \n
			:return: scat: GBAS| SCAT
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.GbasMode)

	def set_mode(self, scat: enums.GbasMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:MODE \n
		Snippet: driver.source.bb.gbas.set_mode(scat = enums.GbasMode.GBAS) \n
		Sets the GBAS mode. Select between GBAS (LAAS) header information or SCAT-I header information. \n
			:param scat: GBAS| SCAT
		"""
		param = Conversions.enum_scalar_to_str(scat, enums.GbasMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:MODE {param}')

	def get_no_frames(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GBAS:NOFRames \n
		Snippet: value: int = driver.source.bb.gbas.get_no_frames() \n
		Queries the number of VDB frames. \n
			:return: no_frame: integer Range: 1 to 12500
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:NOFRames?')
		return Conversions.str_to_int(response)

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:PRESet \n
		Snippet: driver.source.bb.gbas.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:GBAS:STATe. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:PRESet \n
		Snippet: driver.source.bb.gbas.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:GBAS:STATe. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:GBAS:PRESet', opc_timeout_ms)

	def get_scati(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SCATi \n
		Snippet: value: bool = driver.source.bb.gbas.get_scati() \n
		No command help available \n
			:return: scat: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:SCATi?')
		return Conversions.str_to_bool(response)

	def set_scati(self, scat: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SCATi \n
		Snippet: driver.source.bb.gbas.set_scati(scat = False) \n
		No command help available \n
			:param scat: No help available
		"""
		param = Conversions.bool_to_str(scat)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:SCATi {param}')

	def get_sr_info(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:GBAS:SRINfo \n
		Snippet: value: str = driver.source.bb.gbas.get_sr_info() \n
		Queries the used sample rate. \n
			:return: sr_info: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:SRINfo?')
		return trim_str_response(response)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GBAS:STATe \n
		Snippet: value: bool = driver.source.bb.gbas.get_state() \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:STATe \n
		Snippet: driver.source.bb.gbas.set_state(state = False) \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:STATe {param}')

	def get_version(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VERSion \n
		Snippet: value: str = driver.source.bb.gbas.get_version() \n
		Queries the GBAS specification version that corresponds to the set GBAS mode. \n
			:return: version: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GBAS:VERSion?')
		return trim_str_response(response)

	def clone(self) -> 'GbasCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = GbasCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StErrorCls:
	"""StError commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stError", core, parent)

	def set(self, st_error: int, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:TABLe:LONG:SET<CH>:STERror \n
		Snippet: driver.source.bb.btooth.dtTest.table.long.set.stError.set(st_error = 1, channel = repcap.Channel.Default) \n
		Sets a symbol timing error in ppm. This parameter modifies the symbol clock frequency by the set value. \n
			:param st_error: integer Range: -150 to 150, Unit: ppm
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Set')
		"""
		param = Conversions.decimal_value_to_str(st_error)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:DTTest:TABLe:LONG:SET{channel_cmd_val}:STERror {param}')

	def get(self, channel=repcap.Channel.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:DTTest:TABLe:LONG:SET<CH>:STERror \n
		Snippet: value: int = driver.source.bb.btooth.dtTest.table.long.set.stError.get(channel = repcap.Channel.Default) \n
		Sets a symbol timing error in ppm. This parameter modifies the symbol clock frequency by the set value. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Set')
			:return: st_error: integer Range: -150 to 150, Unit: ppm"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:BTOoth:DTTest:TABLe:LONG:SET{channel_cmd_val}:STERror?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScsModeCls:
	"""ScsMode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scsMode", core, parent)

	def set(self, scs_mode: enums.AutoUser, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:SCSMode \n
		Snippet: driver.source.bb.tdscdma.up.cell.enh.dch.scsMode.set(scs_mode = enums.AutoUser.AUTO, cell = repcap.Cell.Default) \n
		Sets the spreading code selection mode for the used transport channels. \n
			:param scs_mode: AUTO| USER
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
		"""
		param = Conversions.enum_scalar_to_str(scs_mode, enums.AutoUser)
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:SCSMode {param}')

	# noinspection PyTypeChecker
	def get(self, cell=repcap.Cell.Default) -> enums.AutoUser:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:SCSMode \n
		Snippet: value: enums.AutoUser = driver.source.bb.tdscdma.up.cell.enh.dch.scsMode.get(cell = repcap.Cell.Default) \n
		Sets the spreading code selection mode for the used transport channels. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: scs_mode: AUTO| USER"""
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:SCSMode?')
		return Conversions.str_to_scalar_enum(response, enums.AutoUser)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RuSelectionCls:
	"""RuSelection commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Station, default value after init: Station.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ruSelection", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_station_get', 'repcap_station_set', repcap.Station.Nr1)

	def repcap_station_set(self, station: repcap.Station) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Station.Default
		Default value after init: Station.Nr1"""
		self._cmd_group.set_repcap_enum_value(station)

	def repcap_station_get(self) -> repcap.Station:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, ru_sel_ch_1: enums.WlannFbPpduRuSel, frameBlock=repcap.FrameBlock.Default, station=repcap.Station.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:CCH1:RUSelection<ST> \n
		Snippet: driver.source.bb.wlnn.fblock.cch1.ruSelection.set(ru_sel_ch_1 = enums.WlannFbPpduRuSel.RU0, frameBlock = repcap.FrameBlock.Default, station = repcap.Station.Default) \n
		For HE frames. Sets the resource unit allocation of the first content channel for the respective channel and station. \n
			:param ru_sel_ch_1: RU0| RU1| RU2| RU3| RU4| RU5| RU6| RU7| RU8| RU9| RU10| RU11| RU12| RU13| RU14| RU15| RU18| RU19| RU20| RU21| RU22| RU23| RU24| RU25| RU34| RU35| RU36| RU37| RU38| RU16| RU17| RU26| RU27| RU28| RU29| RU30| RU31| RU32| RU33
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param station: optional repeated capability selector. Default value: Nr1 (settable in the interface 'RuSelection')
		"""
		param = Conversions.enum_scalar_to_str(ru_sel_ch_1, enums.WlannFbPpduRuSel)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		station_cmd_val = self._cmd_group.get_repcap_cmd_value(station, repcap.Station)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:CCH1:RUSelection{station_cmd_val} {param}')

	# noinspection PyTypeChecker
	def get(self, frameBlock=repcap.FrameBlock.Default, station=repcap.Station.Default) -> enums.WlannFbPpduRuSel:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:CCH1:RUSelection<ST> \n
		Snippet: value: enums.WlannFbPpduRuSel = driver.source.bb.wlnn.fblock.cch1.ruSelection.get(frameBlock = repcap.FrameBlock.Default, station = repcap.Station.Default) \n
		For HE frames. Sets the resource unit allocation of the first content channel for the respective channel and station. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param station: optional repeated capability selector. Default value: Nr1 (settable in the interface 'RuSelection')
			:return: ru_sel_ch_1: RU0| RU1| RU2| RU3| RU4| RU5| RU6| RU7| RU8| RU9| RU10| RU11| RU12| RU13| RU14| RU15| RU18| RU19| RU20| RU21| RU22| RU23| RU24| RU25| RU34| RU35| RU36| RU37| RU38| RU16| RU17| RU26| RU27| RU28| RU29| RU30| RU31| RU32| RU33"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		station_cmd_val = self._cmd_group.get_repcap_cmd_value(station, repcap.Station)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:CCH1:RUSelection{station_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.WlannFbPpduRuSel)

	def clone(self) -> 'RuSelectionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RuSelectionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............Internal.Utilities import trim_str_response
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TpcInstrCls:
	"""TpcInstr commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tpcInstr", core, parent)

	def set(self, tpc_command: str, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:DCIConf:TPCinstr \n
		Snippet: driver.source.bb.eutra.downlink.subf.encc.pdcch.extc.item.dciConf.tpcInstr.set(tpc_command = rawAbc, subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI Format 3/3A field TPC Command. \n
			:param tpc_command: bit pattern The bit pattern length depends on the selected channel bandwidth and is automatically adjusted
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
		"""
		param = Conversions.value_to_str(tpc_command)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._cmd_group.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:DCIConf:TPCinstr {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:DCIConf:TPCinstr \n
		Snippet: value: str = driver.source.bb.eutra.downlink.subf.encc.pdcch.extc.item.dciConf.tpcInstr.get(subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI Format 3/3A field TPC Command. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
			:return: tpc_command: bit pattern The bit pattern length depends on the selected channel bandwidth and is automatically adjusted"""
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._cmd_group.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:DCIConf:TPCinstr?')
		return trim_str_response(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RwindowCls:
	"""Rwindow commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rwindow", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def strajectory(self):
		"""strajectory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_strajectory'):
			from .Strajectory import StrajectoryCls
			self._strajectory = StrajectoryCls(self._core, self._cmd_group)
		return self._strajectory

	def set(self, rep_window: int, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:RPL:RWINdow \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.rpl.rwindow.set(rep_window = 1, vehicle = repcap.Vehicle.Default) \n
		Sets the repeating period (in km) of repeating objects. \n
			:param rep_window: integer Range: 1 to 1E6
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
		"""
		param = Conversions.decimal_value_to_str(rep_window)
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:RPL:RWINdow {param}')

	def get(self, vehicle=repcap.Vehicle.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:RPL:RWINdow \n
		Snippet: value: int = driver.source.bb.gnss.receiver.v.environment.rpl.rwindow.get(vehicle = repcap.Vehicle.Default) \n
		Sets the repeating period (in km) of repeating objects. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: rep_window: integer Range: 1 to 1E6"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:RPL:RWINdow?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'RwindowCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RwindowCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CodeCls:
	"""Code commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("code", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:[BB]:[ILS]:LOCalizer:COMid:CODE:STATe \n
		Snippet: value: bool = driver.source.bb.ils.localizer.comid.code.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:LOCalizer:COMid:CODE:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:[ILS]:LOCalizer:COMid:CODE:STATe \n
		Snippet: driver.source.bb.ils.localizer.comid.code.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:LOCalizer:COMid:CODE:STATe {param}')

	def get_value(self) -> str:
		"""SCPI: [SOURce<HW>]:[BB]:[ILS]:LOCalizer:COMid:CODE \n
		Snippet: value: str = driver.source.bb.ils.localizer.comid.code.get_value() \n
		Sets the coding of the COM/ID signal by the international short name of the airport (e.g. MUC for the Munich airport) .
		The COM/ID tone is sent according to the selected code, see 'Morse code settings'. If no coding is set, the COM/ID tone
		is sent uncoded (key down) . \n
			:return: code: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ILS:LOCalizer:COMid:CODE?')
		return trim_str_response(response)

	def set_value(self, code: str) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:[ILS]:LOCalizer:COMid:CODE \n
		Snippet: driver.source.bb.ils.localizer.comid.code.set_value(code = 'abc') \n
		Sets the coding of the COM/ID signal by the international short name of the airport (e.g. MUC for the Munich airport) .
		The COM/ID tone is sent according to the selected code, see 'Morse code settings'. If no coding is set, the COM/ID tone
		is sent uncoded (key down) . \n
			:param code: string
		"""
		param = Conversions.value_to_quoted_str(code)
		self._core.io.write(f'SOURce<HwInstance>:BB:ILS:LOCalizer:COMid:CODE {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from ..........Internal.Utilities import trim_str_response
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DselectCls:
	"""Dselect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dselect", core, parent)

	def set(self, dselect: str, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:TPC:DATA:DSELect \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.tpc.data.dselect.set(dselect = 'abc', baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command selects the data list for the DLISt data source selection. Power control is available for sub channel types
		F-DCCH and F-FCH. F-DCCH is only generated for radio configurations 3, 4 and 5. The lists are stored as files with the
		fixed file extensions *.dm_iqd in a directory of the user's choice. The directory applicable to the following commands is
		defined with the command method RsSmbv.MassMemory.currentDirectory. To access the files in this directory, you only have
		to give the file name, without the path and the file extension. For the traffic channels, this value is specific for the
		selected radio configuration. \n
			:param dselect: string
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
		"""
		param = Conversions.value_to_quoted_str(dselect)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:TPC:DATA:DSELect {param}')

	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:TPC:DATA:DSELect \n
		Snippet: value: str = driver.source.bb.c2K.bstation.cgroup.coffset.tpc.data.dselect.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command selects the data list for the DLISt data source selection. Power control is available for sub channel types
		F-DCCH and F-FCH. F-DCCH is only generated for radio configurations 3, 4 and 5. The lists are stored as files with the
		fixed file extensions *.dm_iqd in a directory of the user's choice. The directory applicable to the following commands is
		defined with the command method RsSmbv.MassMemory.currentDirectory. To access the files in this directory, you only have
		to give the file name, without the path and the file extension. For the traffic channels, this value is specific for the
		selected radio configuration. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: dselect: string"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:TPC:DATA:DSELect?')
		return trim_str_response(response)



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions
from .. import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class KboardCls:
	"""Kboard commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("kboard", core, parent)

	# noinspection PyTypeChecker
	def get_layout(self) -> enums.KbLayout:
		"""SCPI: KBOard:LAYout \n
		Snippet: value: enums.KbLayout = driver.kboard.get_layout() \n
		Selects the language for an external keyboard and assigns the keys acccordingly. \n
			:return: layout: CHINese| DANish| DUTCh| DUTBe| ENGLish| ENGUK| FINNish| FRENch| FREBe| FRECa| GERMan| ITALian| JAPanese| KORean| NORWegian| PORTuguese| RUSSian| SPANish| SWEDish| ENGUS
		"""
		response = self._core.io.query_str('KBOard:LAYout?')
		return Conversions.str_to_scalar_enum(response, enums.KbLayout)

	def set_layout(self, layout: enums.KbLayout) -> None:
		"""SCPI: KBOard:LAYout \n
		Snippet: driver.kboard.set_layout(layout = enums.KbLayout.CHINese) \n
		Selects the language for an external keyboard and assigns the keys acccordingly. \n
			:param layout: CHINese| DANish| DUTCh| DUTBe| ENGLish| ENGUK| FINNish| FRENch| FREBe| FRECa| GERMan| ITALian| JAPanese| KORean| NORWegian| PORTuguese| RUSSian| SPANish| SWEDish| ENGUS
		"""
		param = Conversions.enum_scalar_to_str(layout, enums.KbLayout)
		self._core.io.write(f'KBOard:LAYout {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PracCls:
	"""Prac commands group definition. 19 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prac", core, parent)

	@property
	def msg(self):
		"""msg commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_msg'):
			from .Msg import MsgCls
			self._msg = MsgCls(self._core, self._cmd_group)
		return self._msg

	@property
	def pts(self):
		"""pts commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_pts'):
			from .Pts import PtsCls
			self._pts = PtsCls(self._core, self._cmd_group)
		return self._pts

	@property
	def slength(self):
		"""slength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_slength'):
			from .Slength import SlengthCls
			self._slength = SlengthCls(self._core, self._cmd_group)
		return self._slength

	def clone(self) -> 'PracCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PracCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DERRor:BIT:STATe \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.derror.bit.state.set(state = False, channelNull = repcap.ChannelNull.Default) \n
		The command activates bit error generation or deactivates it. Bit errors are inserted into the data fields of the
		enhanced channels. When channel coding is active, it is possible to select the layer in which to insert the errors (the
		physical or the transport layer, [:SOURce<hw>]:BB:W3GPp:BSTation:ENHanced:CHANnel<ch0>:DPCH:DERRor:BIT:LAYer) . When the
		data source is read out, individual bits are deliberately inverted at random points in the data bit stream at the
		specified error rate in order to simulate an invalid signal. \n
			:param state: ON| OFF
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
		"""
		param = Conversions.bool_to_str(state)
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DERRor:BIT:STATe {param}')

	def get(self, channelNull=repcap.ChannelNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DERRor:BIT:STATe \n
		Snippet: value: bool = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.derror.bit.state.get(channelNull = repcap.ChannelNull.Default) \n
		The command activates bit error generation or deactivates it. Bit errors are inserted into the data fields of the
		enhanced channels. When channel coding is active, it is possible to select the layer in which to insert the errors (the
		physical or the transport layer, [:SOURce<hw>]:BB:W3GPp:BSTation:ENHanced:CHANnel<ch0>:DPCH:DERRor:BIT:LAYer) . When the
		data source is read out, individual bits are deliberately inverted at random points in the data bit stream at the
		specified error rate in order to simulate an invalid signal. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: state: ON| OFF"""
		channelNull_cmd_val = self._cmd_group.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DERRor:BIT:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhymacCfgCls:
	"""PhymacCfg commands group definition. 7 total commands, 1 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phymacCfg", core, parent)

	@property
	def dpattern(self):
		"""dpattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dpattern'):
			from .Dpattern import DpatternCls
			self._dpattern = DpatternCls(self._core, self._cmd_group)
		return self._dpattern

	# noinspection PyTypeChecker
	def get_coderate(self) -> enums.BtoCodeRate:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:CODERate \n
		Snippet: value: enums.BtoCodeRate = driver.source.bb.btooth.phymacCfg.get_coderate() \n
		No command help available \n
			:return: coderate: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:CODERate?')
		return Conversions.str_to_scalar_enum(response, enums.BtoCodeRate)

	def set_coderate(self, coderate: enums.BtoCodeRate) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:CODERate \n
		Snippet: driver.source.bb.btooth.phymacCfg.set_coderate(coderate = enums.BtoCodeRate.CR_12) \n
		No command help available \n
			:param coderate: No help available
		"""
		param = Conversions.enum_scalar_to_str(coderate, enums.BtoCodeRate)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:CODERate {param}')

	def get_dselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:DSELection \n
		Snippet: value: str = driver.source.bb.btooth.phymacCfg.get_dselection() \n
		No command help available \n
			:return: dselection: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:DSELection?')
		return trim_str_response(response)

	def set_dselection(self, dselection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:DSELection \n
		Snippet: driver.source.bb.btooth.phymacCfg.set_dselection(dselection = 'abc') \n
		No command help available \n
			:param dselection: No help available
		"""
		param = Conversions.value_to_quoted_str(dselection)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:DSELection {param}')

	# noinspection PyTypeChecker
	def get_mac_header(self) -> enums.DataSourceB:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:MACHeader \n
		Snippet: value: enums.DataSourceB = driver.source.bb.btooth.phymacCfg.get_mac_header() \n
		No command help available \n
			:return: mac_header: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:MACHeader?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceB)

	def set_mac_header(self, mac_header: enums.DataSourceB) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:MACHeader \n
		Snippet: driver.source.bb.btooth.phymacCfg.set_mac_header(mac_header = enums.DataSourceB.ALL0) \n
		No command help available \n
			:param mac_header: No help available
		"""
		param = Conversions.enum_scalar_to_str(mac_header, enums.DataSourceB)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:MACHeader {param}')

	# noinspection PyTypeChecker
	def get_payload_cod(self) -> enums.BtoHdrpPayload:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:PAYLoadCod \n
		Snippet: value: enums.BtoHdrpPayload = driver.source.bb.btooth.phymacCfg.get_payload_cod() \n
		No command help available \n
			:return: payload_coding: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:PAYLoadCod?')
		return Conversions.str_to_scalar_enum(response, enums.BtoHdrpPayload)

	def set_payload_cod(self, payload_coding: enums.BtoHdrpPayload) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:PAYLoadCod \n
		Snippet: driver.source.bb.btooth.phymacCfg.set_payload_cod(payload_coding = enums.BtoHdrpPayload.LDPCCOD) \n
		No command help available \n
			:param payload_coding: No help available
		"""
		param = Conversions.enum_scalar_to_str(payload_coding, enums.BtoHdrpPayload)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:PAYLoadCod {param}')

	def get_payload_len(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:PAYLoadLen \n
		Snippet: value: int = driver.source.bb.btooth.phymacCfg.get_payload_len() \n
		No command help available \n
			:return: pay_len: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:PAYLoadLen?')
		return Conversions.str_to_int(response)

	def set_payload_len(self, pay_len: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:PAYLoadLen \n
		Snippet: driver.source.bb.btooth.phymacCfg.set_payload_len(pay_len = 1) \n
		No command help available \n
			:param pay_len: No help available
		"""
		param = Conversions.decimal_value_to_str(pay_len)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:PAYLoadLen {param}')

	def get_prt_aggre(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:PRTAggre \n
		Snippet: value: bool = driver.source.bb.btooth.phymacCfg.get_prt_aggre() \n
		No command help available \n
			:return: parity_aggregation: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:PRTAggre?')
		return Conversions.str_to_bool(response)

	def set_prt_aggre(self, parity_aggregation: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:PHYMacCfg:PRTAggre \n
		Snippet: driver.source.bb.btooth.phymacCfg.set_prt_aggre(parity_aggregation = False) \n
		No command help available \n
			:param parity_aggregation: No help available
		"""
		param = Conversions.bool_to_str(parity_aggregation)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:PHYMacCfg:PRTAggre {param}')

	def clone(self) -> 'PhymacCfgCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PhymacCfgCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 6 total commands, 2 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	@property
	def common(self):
		"""common commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_common'):
			from .Common import CommonCls
			self._common = CommonCls(self._core, self._cmd_group)
		return self._common

	@property
	def fifo(self):
		"""fifo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fifo'):
			from .Fifo import FifoCls
			self._fifo = FifoCls(self._core, self._cmd_group)
		return self._fifo

	def get_max(self) -> int:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:SRATe:MAX \n
		Snippet: value: int = driver.source.iq.output.digital.symbolRate.get_max() \n
		Queries the maximum supported sample rate. \n
			:return: dig_iqhs_in_sr_max: integer Range: 400 to depends on options The maximum value depends on the connected receiving device. For more information, see data sheet.
		"""
		response = self._core.io.query_str('SOURce:IQ:OUTPut:DIGital:SRATe:MAX?')
		return Conversions.str_to_int(response)

	# noinspection PyTypeChecker
	def get_source(self) -> enums.BboutClocSour:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:DIGital:SRATe:SOURce \n
		Snippet: value: enums.BboutClocSour = driver.source.iq.output.digital.symbolRate.get_source() \n
		Queries the sample rate source that is a user-defined value. \n
			:return: source: USER User-defined sample rate source
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:DIGital:SRATe:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.BboutClocSour)

	def set_source(self, source: enums.BboutClocSour) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:DIGital:SRATe:SOURce \n
		Snippet: driver.source.iq.output.digital.symbolRate.set_source(source = enums.BboutClocSour.DOUT) \n
		Queries the sample rate source that is a user-defined value. \n
			:param source: USER User-defined sample rate source
		"""
		param = Conversions.enum_scalar_to_str(source, enums.BboutClocSour)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:DIGital:SRATe:SOURce {param}')

	def get_sum(self) -> int:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:SRATe:SUM \n
		Snippet: value: int = driver.source.iq.output.digital.symbolRate.get_sum() \n
		Queries the maximum supported sample rate. \n
			:return: dig_iqhs_in_sr_sum: integer Range: 400 to depends on options The maximum value depends on the connected receiving device. For more information, see data sheet.
		"""
		response = self._core.io.query_str('SOURce:IQ:OUTPut:DIGital:SRATe:SUM?')
		return Conversions.str_to_int(response)

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:DIGital:SRATe \n
		Snippet: value: float = driver.source.iq.output.digital.symbolRate.get_value() \n
		Sets the sample rate of the digital I/Q output signal. \n
			:return: srate: float Range: 400 to depends on options, Unit: Hz The maximum value depends on the connected receiving device. For more information, see data sheet.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:DIGital:SRATe?')
		return Conversions.str_to_float(response)

	def set_value(self, srate: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:DIGital:SRATe \n
		Snippet: driver.source.iq.output.digital.symbolRate.set_value(srate = 1.0) \n
		Sets the sample rate of the digital I/Q output signal. \n
			:param srate: float Range: 400 to depends on options, Unit: Hz The maximum value depends on the connected receiving device. For more information, see data sheet.
		"""
		param = Conversions.decimal_value_to_str(srate)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:DIGital:SRATe {param}')

	def clone(self) -> 'SymbolRateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SymbolRateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FconfigurationCls:
	"""Fconfiguration commands group definition. 16 total commands, 9 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fconfiguration", core, parent)

	@property
	def bmode(self):
		"""bmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bmode'):
			from .Bmode import BmodeCls
			self._bmode = BmodeCls(self._core, self._cmd_group)
		return self._bmode

	@property
	def cmode(self):
		"""cmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cmode'):
			from .Cmode import CmodeCls
			self._cmode = CmodeCls(self._core, self._cmd_group)
		return self._cmode

	@property
	def data(self):
		"""data commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def eactive(self):
		"""eactive commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_eactive'):
			from .Eactive import EactiveCls
			self._eactive = EactiveCls(self._core, self._cmd_group)
		return self._eactive

	@property
	def hactive(self):
		"""hactive commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hactive'):
			from .Hactive import HactiveCls
			self._hactive = HactiveCls(self._core, self._cmd_group)
		return self._hactive

	@property
	def iactive(self):
		"""iactive commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iactive'):
			from .Iactive import IactiveCls
			self._iactive = IactiveCls(self._core, self._cmd_group)
		return self._iactive

	@property
	def pcrc(self):
		"""pcrc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pcrc'):
			from .Pcrc import PcrcCls
			self._pcrc = PcrcCls(self._core, self._cmd_group)
		return self._pcrc

	@property
	def prcMode(self):
		"""prcMode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prcMode'):
			from .PrcMode import PrcModeCls
			self._prcMode = PrcModeCls(self._core, self._cmd_group)
		return self._prcMode

	@property
	def rbit(self):
		"""rbit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbit'):
			from .Rbit import RbitCls
			self._rbit = RbitCls(self._core, self._cmd_group)
		return self._rbit

	# noinspection PyTypeChecker
	def get_crate(self) -> enums.LoRaCodRate:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:CRATe \n
		Snippet: value: enums.LoRaCodRate = driver.source.bb.lora.fconfiguration.get_crate() \n
		Sets the coding rate. \n
			:return: crate: CR0| CR1| CR2| CR3| CR4 CRx = 0 to 4 The coding rate RCoding is calculated as follows: RCoding = 4 / (4 + CRx) 'CR0' corresponds to no coding, i.e. RCoding = 1.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:LORA:FCONfiguration:CRATe?')
		return Conversions.str_to_scalar_enum(response, enums.LoRaCodRate)

	def set_crate(self, crate: enums.LoRaCodRate) -> None:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:CRATe \n
		Snippet: driver.source.bb.lora.fconfiguration.set_crate(crate = enums.LoRaCodRate.CR0) \n
		Sets the coding rate. \n
			:param crate: CR0| CR1| CR2| CR3| CR4 CRx = 0 to 4 The coding rate RCoding is calculated as follows: RCoding = 4 / (4 + CRx) 'CR0' corresponds to no coding, i.e. RCoding = 1.
		"""
		param = Conversions.enum_scalar_to_str(crate, enums.LoRaCodRate)
		self._core.io.write(f'SOURce<HwInstance>:BB:LORA:FCONfiguration:CRATe {param}')

	def get_dlength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:DLENgth \n
		Snippet: value: int = driver.source.bb.lora.fconfiguration.get_dlength() \n
		Sets the data length of the payload in the frame. \n
			:return: dlength: integer Range: 1 to 255
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:LORA:FCONfiguration:DLENgth?')
		return Conversions.str_to_int(response)

	def set_dlength(self, dlength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:DLENgth \n
		Snippet: driver.source.bb.lora.fconfiguration.set_dlength(dlength = 1) \n
		Sets the data length of the payload in the frame. \n
			:param dlength: integer Range: 1 to 255
		"""
		param = Conversions.decimal_value_to_str(dlength)
		self._core.io.write(f'SOURce<HwInstance>:BB:LORA:FCONfiguration:DLENgth {param}')

	# noinspection PyTypeChecker
	def get_sfactor(self) -> enums.LoRaSf:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:SFACtor \n
		Snippet: value: enums.LoRaSf = driver.source.bb.lora.fconfiguration.get_sfactor() \n
		Sets the spreading factor for the modulation. \n
			:return: sf: SF6| SF7| SF8| SF9| SF10| SF11| SF12
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:LORA:FCONfiguration:SFACtor?')
		return Conversions.str_to_scalar_enum(response, enums.LoRaSf)

	def set_sfactor(self, sf: enums.LoRaSf) -> None:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:SFACtor \n
		Snippet: driver.source.bb.lora.fconfiguration.set_sfactor(sf = enums.LoRaSf.SF10) \n
		Sets the spreading factor for the modulation. \n
			:param sf: SF6| SF7| SF8| SF9| SF10| SF11| SF12
		"""
		param = Conversions.enum_scalar_to_str(sf, enums.LoRaSf)
		self._core.io.write(f'SOURce<HwInstance>:BB:LORA:FCONfiguration:SFACtor {param}')

	# noinspection PyTypeChecker
	def get_smode(self) -> enums.LoRaSyncMode:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:SMODe \n
		Snippet: value: enums.LoRaSyncMode = driver.source.bb.lora.fconfiguration.get_smode() \n
		Sets the synchronization mode of the preamble. \n
			:return: smode: PRIVate| PUBLic PRIVate A preamble with a public sync word is generated. PUBLic A preamble with a private sync word is generated.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:LORA:FCONfiguration:SMODe?')
		return Conversions.str_to_scalar_enum(response, enums.LoRaSyncMode)

	def set_smode(self, smode: enums.LoRaSyncMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:SMODe \n
		Snippet: driver.source.bb.lora.fconfiguration.set_smode(smode = enums.LoRaSyncMode.PRIVate) \n
		Sets the synchronization mode of the preamble. \n
			:param smode: PRIVate| PUBLic PRIVate A preamble with a public sync word is generated. PUBLic A preamble with a private sync word is generated.
		"""
		param = Conversions.enum_scalar_to_str(smode, enums.LoRaSyncMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:LORA:FCONfiguration:SMODe {param}')

	def get_up_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:UPLength \n
		Snippet: value: int = driver.source.bb.lora.fconfiguration.get_up_length() \n
		Sets the unmodulated preamble length. \n
			:return: plength: integer Range: 6 to 8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:LORA:FCONfiguration:UPLength?')
		return Conversions.str_to_int(response)

	def set_up_length(self, plength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:LORA:FCONfiguration:UPLength \n
		Snippet: driver.source.bb.lora.fconfiguration.set_up_length(plength = 1) \n
		Sets the unmodulated preamble length. \n
			:param plength: integer Range: 6 to 8
		"""
		param = Conversions.decimal_value_to_str(plength)
		self._core.io.write(f'SOURce<HwInstance>:BB:LORA:FCONfiguration:UPLength {param}')

	def clone(self) -> 'FconfigurationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FconfigurationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScaleCls:
	"""Scale commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scale", core, parent)

	def set(self, reference_scale: enums.RefScale, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:SCALe \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.full.scale.set(reference_scale = enums.RefScale.DISTance, vehicle = repcap.Vehicle.Default) \n
		Defines whether the obstacles' positions are defined as distance (in km) or as time (in s) . \n
			:param reference_scale: TIME| DISTance
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
		"""
		param = Conversions.enum_scalar_to_str(reference_scale, enums.RefScale)
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:SCALe {param}')

	# noinspection PyTypeChecker
	def get(self, vehicle=repcap.Vehicle.Default) -> enums.RefScale:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:SCALe \n
		Snippet: value: enums.RefScale = driver.source.bb.gnss.receiver.v.environment.full.scale.get(vehicle = repcap.Vehicle.Default) \n
		Defines whether the obstacles' positions are defined as distance (in km) or as time (in s) . \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: reference_scale: TIME| DISTance"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:SCALe?')
		return Conversions.str_to_scalar_enum(response, enums.RefScale)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TpTimeCls:
	"""TpTime commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tpTime", core, parent)

	def set(self, trig_proc_time: enums.WlannFbTrigFrmMinTrigProcTime, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:TFConfig:TPTime \n
		Snippet: driver.source.bb.wlnn.fblock.user.tfConfig.tpTime.set(trig_proc_time = enums.WlannFbTrigFrmMinTrigProcTime.TPT0, frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Sets minimum time to process the trigger frame in microseconds. \n
			:param trig_proc_time: TPT0| TPT8| TPT16 TPT0|TPT8|TPT16 0/8/16 us
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.enum_scalar_to_str(trig_proc_time, enums.WlannFbTrigFrmMinTrigProcTime)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:TFConfig:TPTime {param}')

	# noinspection PyTypeChecker
	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> enums.WlannFbTrigFrmMinTrigProcTime:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:TFConfig:TPTime \n
		Snippet: value: enums.WlannFbTrigFrmMinTrigProcTime = driver.source.bb.wlnn.fblock.user.tfConfig.tpTime.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Sets minimum time to process the trigger frame in microseconds. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: trig_proc_time: TPT0| TPT8| TPT16 TPT0|TPT8|TPT16 0/8/16 us"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:TFConfig:TPTime?')
		return Conversions.str_to_scalar_enum(response, enums.WlannFbTrigFrmMinTrigProcTime)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MsettingsCls:
	"""Msettings commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("msettings", core, parent)

	def get_fdeviation(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:MSETtings:FDEViation \n
		Snippet: value: float = driver.source.bb.btooth.msettings.get_fdeviation() \n
		Sets the frequency deviation. \n
			:return: fdeviation: float Range: Depends on Bluetooth mode
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:MSETtings:FDEViation?')
		return Conversions.str_to_float(response)

	def set_fdeviation(self, fdeviation: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:MSETtings:FDEViation \n
		Snippet: driver.source.bb.btooth.msettings.set_fdeviation(fdeviation = 1.0) \n
		Sets the frequency deviation. \n
			:param fdeviation: float Range: Depends on Bluetooth mode
		"""
		param = Conversions.decimal_value_to_str(fdeviation)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:MSETtings:FDEViation {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExternalCls:
	"""External commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("external", core, parent)

	# noinspection PyTypeChecker
	def get_impedance(self) -> enums.InputImpRf:
		"""SCPI: [SOURce<HW>]:PULM:TRIGger:EXTernal:IMPedance \n
		Snippet: value: enums.InputImpRf = driver.source.pulm.trigger.external.get_impedance() \n
		No command help available \n
			:return: impedance: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:PULM:TRIGger:EXTernal:IMPedance?')
		return Conversions.str_to_scalar_enum(response, enums.InputImpRf)

	def set_impedance(self, impedance: enums.InputImpRf) -> None:
		"""SCPI: [SOURce<HW>]:PULM:TRIGger:EXTernal:IMPedance \n
		Snippet: driver.source.pulm.trigger.external.set_impedance(impedance = enums.InputImpRf.G10K) \n
		No command help available \n
			:param impedance: No help available
		"""
		param = Conversions.enum_scalar_to_str(impedance, enums.InputImpRf)
		self._core.io.write(f'SOURce<HwInstance>:PULM:TRIGger:EXTernal:IMPedance {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CidGroupCls:
	"""CidGroup commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cidGroup", core, parent)

	def get(self, carrier=repcap.Carrier.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CARRier<CH>:NIOT:CIDGroup \n
		Snippet: value: int = driver.source.bb.eutra.downlink.carrier.niot.cidGroup.get(carrier = repcap.Carrier.Default) \n
		Queries the physical cell identity group. \n
			:param carrier: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Carrier')
			:return: cell_id_gr: integer Range: 0 to 111"""
		carrier_cmd_val = self._cmd_group.get_repcap_cmd_value(carrier, repcap.Carrier)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:CARRier{carrier_cmd_val}:NIOT:CIDGroup?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdCls:
	"""Id commands group definition. 14 total commands, 2 Subgroups, 11 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("id", core, parent)

	@property
	def code(self):
		"""code commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_code'):
			from .Code import CodeCls
			self._code = CodeCls(self._core, self._cmd_group)
		return self._code

	@property
	def ppp(self):
		"""ppp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ppp'):
			from .Ppp import PppCls
			self._ppp = PppCls(self._core, self._cmd_group)
		return self._ppp

	def get_dash(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:DASH \n
		Snippet: value: float = driver.source.bb.dme.id.get_dash() \n
		Sets the length of a Morse code dash. Available only if [:SOURce<hw>][:BB]:DME:ID:TSCHema is set to USER. \n
			:return: dash: float Range: 0.05 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:DASH?')
		return Conversions.str_to_float(response)

	def set_dash(self, dash: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:DASH \n
		Snippet: driver.source.bb.dme.id.set_dash(dash = 1.0) \n
		Sets the length of a Morse code dash. Available only if [:SOURce<hw>][:BB]:DME:ID:TSCHema is set to USER. \n
			:param dash: float Range: 0.05 to 1
		"""
		param = Conversions.decimal_value_to_str(dash)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:DASH {param}')

	def get_dot(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:DOT \n
		Snippet: value: float = driver.source.bb.dme.id.get_dot() \n
		Sets the length of a Morse code dot. \n
			:return: dot: float Range: 0.05 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:DOT?')
		return Conversions.str_to_float(response)

	def set_dot(self, dot: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:DOT \n
		Snippet: driver.source.bb.dme.id.set_dot(dot = 1.0) \n
		Sets the length of a Morse code dot. \n
			:param dot: float Range: 0.05 to 1
		"""
		param = Conversions.decimal_value_to_str(dot)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:DOT {param}')

	def get_dot_length(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:DOTLength \n
		Snippet: value: float = driver.source.bb.dme.id.get_dot_length() \n
		No command help available \n
			:return: dot_length: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:DOTLength?')
		return Conversions.str_to_float(response)

	def set_dot_length(self, dot_length: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:DOTLength \n
		Snippet: driver.source.bb.dme.id.set_dot_length(dot_length = 1.0) \n
		No command help available \n
			:param dot_length: No help available
		"""
		param = Conversions.decimal_value_to_str(dot_length)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:DOTLength {param}')

	def get_letter(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:LETTer \n
		Snippet: value: float = driver.source.bb.dme.id.get_letter() \n
		Sets the length of a Morse code letter space. Available only if [:SOURce<hw>][:BB]:DME:ID:TSCHema is set to USER. \n
			:return: letter: float Range: 0.05 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:LETTer?')
		return Conversions.str_to_float(response)

	def set_letter(self, letter: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:LETTer \n
		Snippet: driver.source.bb.dme.id.set_letter(letter = 1.0) \n
		Sets the length of a Morse code letter space. Available only if [:SOURce<hw>][:BB]:DME:ID:TSCHema is set to USER. \n
			:param letter: float Range: 0.05 to 1
		"""
		param = Conversions.decimal_value_to_str(letter)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:LETTer {param}')

	def get_period(self) -> int:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:PERiod \n
		Snippet: value: int = driver.source.bb.dme.id.get_period() \n
		Sets the period of the COM/ID signal. \n
			:return: period: integer Range: 10 to 120
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:PERiod?')
		return Conversions.str_to_int(response)

	def set_period(self, period: int) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:PERiod \n
		Snippet: driver.source.bb.dme.id.set_period(period = 1) \n
		Sets the period of the COM/ID signal. \n
			:param period: integer Range: 10 to 120
		"""
		param = Conversions.decimal_value_to_str(period)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:PERiod {param}')

	def get_pps(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:PPS \n
		Snippet: value: float = driver.source.bb.dme.id.get_pps() \n
		Sets the morse pulse pair spacing. \n
			:return: pulse_pair_spacing: float Range: 2E-6 to 300E-6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:PPS?')
		return Conversions.str_to_float(response)

	def set_pps(self, pulse_pair_spacing: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:PPS \n
		Snippet: driver.source.bb.dme.id.set_pps(pulse_pair_spacing = 1.0) \n
		Sets the morse pulse pair spacing. \n
			:param pulse_pair_spacing: float Range: 2E-6 to 300E-6
		"""
		param = Conversions.decimal_value_to_str(pulse_pair_spacing)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:PPS {param}')

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:PRESet \n
		Snippet: driver.source.bb.dme.id.preset() \n
		Sets the default settings for the ID signal. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:PRESet \n
		Snippet: driver.source.bb.dme.id.preset_with_opc() \n
		Sets the default settings for the ID signal. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:DME:ID:PRESet', opc_timeout_ms)

	def get_rate(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:RATE \n
		Snippet: value: float = driver.source.bb.dme.id.get_rate() \n
		Sets the pulse repetition rate of the ID sequence. \n
			:return: rate: float Range: 100 to 10E3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:RATE?')
		return Conversions.str_to_float(response)

	def set_rate(self, rate: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:RATE \n
		Snippet: driver.source.bb.dme.id.set_rate(rate = 1.0) \n
		Sets the pulse repetition rate of the ID sequence. \n
			:param rate: float Range: 100 to 10E3
		"""
		param = Conversions.decimal_value_to_str(rate)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:RATE {param}')

	def get_symbol(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:SYMBol \n
		Snippet: value: float = driver.source.bb.dme.id.get_symbol() \n
		Sets the length of the Morse code symbol space. Available only if [:SOURce<hw>][:BB]:DME:ID:TSCHema is set to USER. \n
			:return: symbol: float Range: 0.05 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:SYMBol?')
		return Conversions.str_to_float(response)

	def set_symbol(self, symbol: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:SYMBol \n
		Snippet: driver.source.bb.dme.id.set_symbol(symbol = 1.0) \n
		Sets the length of the Morse code symbol space. Available only if [:SOURce<hw>][:BB]:DME:ID:TSCHema is set to USER. \n
			:param symbol: float Range: 0.05 to 1
		"""
		param = Conversions.decimal_value_to_str(symbol)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:SYMBol {param}')

	# noinspection PyTypeChecker
	def get_tschema(self) -> enums.AvionicComIdTimeSchem:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:TSCHema \n
		Snippet: value: enums.AvionicComIdTimeSchem = driver.source.bb.dme.id.get_tschema() \n
		Sets the time schema of the Morse code for the COM/ID signal. \n
			:return: tschema: STD| USER
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:TSCHema?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicComIdTimeSchem)

	def set_tschema(self, tschema: enums.AvionicComIdTimeSchem) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:TSCHema \n
		Snippet: driver.source.bb.dme.id.set_tschema(tschema = enums.AvionicComIdTimeSchem.STD) \n
		Sets the time schema of the Morse code for the COM/ID signal. \n
			:param tschema: STD| USER
		"""
		param = Conversions.enum_scalar_to_str(tschema, enums.AvionicComIdTimeSchem)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:TSCHema {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:[STATe] \n
		Snippet: value: bool = driver.source.bb.dme.id.get_state() \n
		Enables/disables the COM/ID signal. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ID:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ID:[STATe] \n
		Snippet: driver.source.bb.dme.id.set_state(state = False) \n
		Enables/disables the COM/ID signal. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ID:STATe {param}')

	def clone(self) -> 'IdCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IdCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CsiCls:
	"""Csi commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("csi", core, parent)

	@property
	def lresponse(self):
		"""lresponse commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lresponse'):
			from .Lresponse import LresponseCls
			self._lresponse = LresponseCls(self._core, self._cmd_group)
		return self._lresponse

	@property
	def rtSize(self):
		"""rtSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rtSize'):
			from .RtSize import RtSizeCls
			self._rtSize = RtSizeCls(self._core, self._cmd_group)
		return self._rtSize

	def clone(self) -> 'CsiCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CsiCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from ..........Internal.Utilities import trim_str_response
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UserCls:
	"""User commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("user", core, parent)

	def set(self, user: str, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:SYNC:USER \n
		Snippet: driver.source.bb.gsm.frame.slot.subChannel.user.sync.user.set(user = rawAbc, frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		The command outputs the bit pattern of the User Sync sequence for the Access burst. The length is 64 bits. Superfluous
		bits are truncated on input. Missing bits are filled with 0. The command is valid only for selection BB:GSM:SLOT:SYNC:SEL
		USER and for burst type selection BB:GSM:SLOT:TYPE ACC. \n
			:param user: integer Range: #B0,1 to #B111...,41
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.value_to_str(user)
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:SYNC:USER {param}')

	def get(self, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:SYNC:USER \n
		Snippet: value: str = driver.source.bb.gsm.frame.slot.subChannel.user.sync.user.get(frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		The command outputs the bit pattern of the User Sync sequence for the Access burst. The length is 64 bits. Superfluous
		bits are truncated on input. Missing bits are filled with 0. The command is valid only for selection BB:GSM:SLOT:SYNC:SEL
		USER and for burst type selection BB:GSM:SLOT:TYPE ACC. \n
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: user: integer Range: #B0,1 to #B111...,41"""
		frameIx_cmd_val = self._cmd_group.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:SYNC:USER?')
		return trim_str_response(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UplinkCls:
	"""Uplink commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uplink", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SETTing:TMODel:UL:CATalog \n
		Snippet: value: List[str] = driver.source.bb.nr5G.setting.tmodel.uplink.get_catalog() \n
		Queries the filenames of predefined files with test signals in the default directory. \n
			:return: nr_5_gcat_name_tmod_up: filename1,filename2,... Returns a string of filenames separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:SETTing:TMODel:UL:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_value(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SETTing:TMODel:UL \n
		Snippet: value: str = driver.source.bb.nr5G.setting.tmodel.uplink.get_value() \n
		Loads a test model file with predefined settings. \n
			:return: tmod_up: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:SETTing:TMODel:UL?')
		return trim_str_response(response)

	def set_value(self, tmod_up: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SETTing:TMODel:UL \n
		Snippet: driver.source.bb.nr5G.setting.tmodel.uplink.set_value(tmod_up = 'abc') \n
		Loads a test model file with predefined settings. \n
			:param tmod_up: 'filename' Filename as queried with one of the following commands: [:SOURcehw]:BB:NR5G:SETTing:TMODel:UL:CATalog? [:SOURcehw]:BB:NR5G:SETTing:TMODel:DL:CATalog? [:SOURcehw]:BB:NR5G:SETTing:TMODel:FILTer:CATalog
		"""
		param = Conversions.value_to_quoted_str(tmod_up)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SETTing:TMODel:UL {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class E5AhsCls:
	"""E5Ahs commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("e5Ahs", core, parent)

	def set(self, hs_e_5_a: int, satelliteSvid=repcap.SatelliteSvid.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GALileo:NMESsage:FNAV:E5AHS \n
		Snippet: driver.source.bb.gnss.svid.galileo.nmessage.fnav.e5Ahs.set(hs_e_5_a = 1, satelliteSvid = repcap.SatelliteSvid.Default) \n
		Sets the signal health status - E5aHS parameter. \n
			:param hs_e_5_a: integer Range: -1 to 1
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
		"""
		param = Conversions.decimal_value_to_str(hs_e_5_a)
		satelliteSvid_cmd_val = self._cmd_group.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GALileo:NMESsage:FNAV:E5AHS {param}')

	def get(self, satelliteSvid=repcap.SatelliteSvid.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GALileo:NMESsage:FNAV:E5AHS \n
		Snippet: value: int = driver.source.bb.gnss.svid.galileo.nmessage.fnav.e5Ahs.get(satelliteSvid = repcap.SatelliteSvid.Default) \n
		Sets the signal health status - E5aHS parameter. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:return: hs_e_5_a: integer Range: -1 to 1"""
		satelliteSvid_cmd_val = self._cmd_group.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GALileo:NMESsage:FNAV:E5AHS?')
		return Conversions.str_to_int(response)
